@@ -47,23 +47,32 @@ class CreateEaiJupyterRequest(RpcRequest):
 
 	def set_EaisType(self, EaisType):  # String
 		self.add_query_param('EaisType', EaisType)
-	def get_VSwitchId(self): # String
-		return self.get_query_params().get('VSwitchId')
-
-	def set_VSwitchId(self, VSwitchId):  # String
-		self.add_query_param('VSwitchId', VSwitchId)
 	def get_ResourceGroupId(self): # String
 		return self.get_query_params().get('ResourceGroupId')
 
 	def set_ResourceGroupId(self, ResourceGroupId):  # String
 		self.add_query_param('ResourceGroupId', ResourceGroupId)
-	def get_EnvironmentVar(self): # Array
-		return self.get_query_params().get('EnvironmentVar')
-
-	def set_EnvironmentVar(self, EnvironmentVar):  # Array
-		self.add_query_param("EnvironmentVar", json.dumps(EnvironmentVar))
 	def get_EaisName(self): # String
 		return self.get_query_params().get('EaisName')
 
 	def set_EaisName(self, EaisName):  # String
 		self.add_query_param('EaisName', EaisName)
+	def get_Tags(self): # RepeatList
+		return self.get_query_params().get('Tag')
+
+	def set_Tags(self, Tag):  # RepeatList
+		for depth1 in range(len(Tag)):
+			if Tag[depth1].get('Value') is not None:
+				self.add_query_param('Tag.' + str(depth1 + 1) + '.Value', Tag[depth1].get('Value'))
+			if Tag[depth1].get('Key') is not None:
+				self.add_query_param('Tag.' + str(depth1 + 1) + '.Key', Tag[depth1].get('Key'))
+	def get_VSwitchId(self): # String
+		return self.get_query_params().get('VSwitchId')
+
+	def set_VSwitchId(self, VSwitchId):  # String
+		self.add_query_param('VSwitchId', VSwitchId)
+	def get_EnvironmentVar(self): # Array
+		return self.get_query_params().get('EnvironmentVar')
+
+	def set_EnvironmentVar(self, EnvironmentVar):  # Array
+		self.add_query_param("EnvironmentVar", json.dumps(EnvironmentVar))
